from vcCommand import *
import os.path

app = getApplication()
teach = getApplication().TeachContext

def SelectMode(args):
  if mode.Value == "Component":
    component.IsVisible = True
    componentNode.IsVisible = False
    componentFeature.IsVisible = False
  if mode.Value == "Component.Node":
    componentNode.IsVisible = True
    component.IsVisible = False
    componentFeature.IsVisible = False
  if mode.Value == "Component.Feature":
    componentFeature.IsVisible = True
    componentNode.IsVisible = False
    component.IsVisible = False

def OnStart():
  routine = teach.ActiveScope
  
  icon_path = getCommandPath()[8:]
  base, filename = os.path.split(icon_path)
  icon_path = os.path.join(base, 'hidden_icon.svg')
  
  processStatement = routine.addStatement(VC_STATEMENT_PROCESS, teach.ActiveStatementIndex + 1, icon_path)
  processStatement.Name = "Visible"+str(teach.ActiveStatementIndex+1)
  
  processStatement.createProperty(VC_STRING, 'Mode', VC_PROPERTY_STEP)
  processStatement.createProperty(VC_STRING, 'Component')
  processStatement.createProperty(VC_STRING, 'Component.Node')
  processStatement.createProperty(VC_STRING, 'Component.Feature')
  processStatement.createProperty(VC_BUTTON, 'SelectTarget')
  processStatement.createProperty(VC_BOOLEAN, 'Visible')
  processStatement.createProperty(VC_BOOLEAN, 'Reset')
  
  global mode, component, componentNode, componentFeature
  mode = processStatement.getProperty('Mode')
  component = processStatement.getProperty('Component')
  componentNode = processStatement.getProperty('Component.Node')
  componentFeature = processStatement.getProperty('Component.Feature')
  
  component.IsVisible = False
  componentNode.IsVisible = False
  componentFeature.IsVisible = False
  
  mode.StepValues = ["Component","Component.Node","Component.Feature"]
  mode.OnChanged = SelectMode
  

  robot = teach.ActiveRobot 
  visibleStatementScriptName = 'StatementScript_' + processStatement.Name
  visibleStatementScript = robot.findBehaviour(visibleStatementScriptName)
  if not visibleStatementScript:
    visibleStatementScript = robot.createBehaviour(VC_PYTHONPROCESSHANDLER, visibleStatementScriptName)
  visibleStatementScript.Script = '''
from vcPythonProcessHandler import *
import vcVector

app = getApplication()
snap = app.findCommand('interactiveSnap') 

def ChildPicked(arg):
  global mode, component, componentNode, componentFeature, newComponent, material
  if mode.Value == "Component":
    target = snap.TargetNode.Component
    component.Value = target.Name
  if mode.Value == "Component.Node":
    newComponent = snap.TargetNode.Component
    target = snap.TargetNode
    componentNode.Value = target.Name
  if mode.Value == "Component.Feature":
    material = snap.TargetGeoset.Material
    newComponent = snap.TargetNode.Component
    target = snap.TargetGeoset.Feature
    componentFeature.Value = target.Name
  
def OnPickComponent(arg):
  snap.clear()   
  snap.OnTargetSet = ChildPicked   
  snap.execute()

def hideOthers(statement):
  name = statement.getProperty('Name')
  name.IsVisible = False
  base = statement.getProperty('Base')
  base.IsVisible = False
  tool = statement.getProperty('Tool')
  tool.IsVisible = False

def setEvents(statement):
  global mode, component, componentNode, componentFeature, booleanSignal, reset
  
  mode = statement.getProperty('Mode')
  component = statement.getProperty('Component')
  componentNode = statement.getProperty('Component.Node')
  componentFeature = statement.getProperty('Component.Feature')
  booleanSignal = statement.getProperty('Visible')
  reset = statement.getProperty('Reset')
  
  global selectTarget
  selectTarget = statement.getProperty('SelectTarget')
  if selectTarget:
    if not selectTarget.OnChanged:
      selectTarget.OnChanged = OnPickComponent

def OnStatementAdd(statement):
  # Hide others
  hideOthers(statement)
  # Set events
  setEvents(statement)

def OnStatementModified(statement):
  # Hide others
  hideOthers(statement)
  # Set events
  setEvents(statement)
  
def OnStatementExecute(executor, statement):  
  # Hide others
  hideOthers(statement)
  # Set events
  setEvents(statement)
  
  if mode.Value == "Component":
    assembly = app.findComponent(component.Value)
    assembly.Visible = booleanSignal.Value
  if mode.Value == "Component.Node":
    assembly = app.findComponent(newComponent.Name)
    node = assembly.findNode(componentNode.Value)
    node.Visible = booleanSignal.Value
  if mode.Value == "Component.Feature":
    assembly = app.findComponent(newComponent.Name)
    feature = assembly.findFeature(componentFeature.Value)
    geometrySets=feature.Geometry.GeometrySets
    for geometrySet in geometrySets:
      geometrySet.Material = material
    feature.Visible = booleanSignal.Value
    feature.rebuild()

def OnReset():
  if reset.Value == True:
    if mode.Value == "Component":
      assembly = app.findComponent(component.Value)
      assembly.Visible = True
    if mode.Value == "Component.Node":
      assembly = app.findComponent(newComponent.Name)
      node = assembly.findNode(componentNode.Value)
      node.Visible = True
    if mode.Value == "Component.Feature":
      assembly = app.findComponent(newComponent.Name)
      feature = assembly.findFeature(componentFeature.Value)
      geometrySets=feature.Geometry.GeometrySets
      for geometrySet in geometrySets:
        geometrySet.Material = material
      feature.Visible = True
      feature.rebuild()



'''
  processStatement.Process = visibleStatementScript
  app.SelectionManager.setSelection(processStatement)

